is_misc_function_key

Function is_misc_function_key 

pub fn is_misc_function_key(keysym: Keysym) -> bool
👎Deprecated:

the xkeysym crate implements this crate without any cruft

Tell whether a key is a miscellaneous function key.