pub struct KeyboardState { /* private fields */ }the xkeysym crate implements this crate without any cruft
Keeps track of the keyboard state for the X11 display.
Implementations
Sourceimpl KeyboardState
impl KeyboardState
Sourcepub fn new(dpy: &mut impl Display) -> Result<Self>
👎Deprecated: the xkeysym crate implements this crate without any cruft
pub fn new(dpy: &mut impl Display) -> Result<Self>
the xkeysym crate implements this crate without any cruft
Create a new KeyboardState associated with the given connection.
Sourcepub async fn new_async(dpy: &mut impl AsyncDisplay) -> Result<Self>
👎Deprecated: the xkeysym crate implements this crate without any cruft
pub async fn new_async(dpy: &mut impl AsyncDisplay) -> Result<Self>
the xkeysym crate implements this crate without any cruft
Create a new KeyboardState, async redox.
Sourcepub fn refresh(&mut self, dpy: &mut impl Display) -> Result<()>
👎Deprecated: the xkeysym crate implements this crate without any cruft
pub fn refresh(&mut self, dpy: &mut impl Display) -> Result<()>
the xkeysym crate implements this crate without any cruft
Refresh the keyboard mapping associated with this type.
Sourcepub async fn refresh_async(&mut self, dpy: &mut impl AsyncDisplay) -> Result<()>
👎Deprecated: the xkeysym crate implements this crate without any cruft
pub async fn refresh_async(&mut self, dpy: &mut impl AsyncDisplay) -> Result<()>
the xkeysym crate implements this crate without any cruft
Refresh the keyboard mapping associated with this type, async redox.
Sourcepub fn symbol(
&mut self,
dpy: &mut impl Display,
keycode: Keycode,
column: u8,
) -> Result<Keysym>
👎Deprecated: the xkeysym crate implements this crate without any cruft
pub fn symbol( &mut self, dpy: &mut impl Display, keycode: Keycode, column: u8, ) -> Result<Keysym>
the xkeysym crate implements this crate without any cruft
Get the keyboard symbol associated with the keycode and the column.
Sourcepub async fn symbol_async(
&mut self,
dpy: &mut impl AsyncDisplay,
keycode: Keycode,
column: u8,
) -> Result<Keysym>
👎Deprecated: the xkeysym crate implements this crate without any cruft
pub async fn symbol_async( &mut self, dpy: &mut impl AsyncDisplay, keycode: Keycode, column: u8, ) -> Result<Keysym>
the xkeysym crate implements this crate without any cruft
Get the keyboard symbol associated with the keycode and the column, async redox.